
References
==========

Some of the papers that the algorithms within curver are based on:

.. [Bell15] `Recognising mapping classes <http://wrap.warwick.ac.uk/77123/>`_
.. [Bell16] `Simplifying triangulations <https://arxiv.org/abs/1604.04314>`_
.. [BellWebb16] `Polynomial-time algorithms for the curve graph <https://arxiv.org/abs/1609.09392>`_
.. [Bow08] `Tight geodesics in the curve complex <https://link.springer.com/article/10.1007/s00222-007-0081-y>`_
.. [FarbMarg12] A primer on mapping class groups
.. [GadreTsai11] `Minimal pseudo-Anosov translation lengths on the complex of curves <https://arxiv.org/abs/1101.2692>`_
.. [Webb15] `Combinatorics of tight geodesics and stable lengths <https://arxiv.org/abs/1305.3566>`_

